// Run tests.c by following the instructions below:

// This file contains passing tests.

// Run them by opening a terminal and running the following:
// $ make Season-1/Level-2/tests && ./Season-1/Level-2/tests

#include "code.h"

int main() {
    // Creates an admin username called "alice"
    int user1 = create_user_account(true, "alice");
    // Creates a non-admin username called "bob"
    int user2 = create_user_account(false, "bob");

    // check who is admin
    print_is_admin() ;

    // Updates the setting '2' of user1 to the number '10'
    update_setting(user2, "2", "10");
    
    // check who is admin
    print_is_admin() ;
    return 0;
}
